/**
 * A structure definition for the Alert Rule object.
 * This class is dynamic so new properties can be added to instances as needed.
 */
dynamic class AlertRuleItem {
	
	/**
	 * A unique id for an Alert Rule instance.
	 */
	public var id:Number = -1;
	
	/**
	 * An indicator of how this alert should be treated. The value should be
	 * one of the notification level contants.
	 */
	public var alert:Number = 0;
	
	/**
	 * The stock symbol for this rule.
	 */
	public var symbol:String = "";	
	
	/**
	 * The value to compare against.
	 */
	public var value:String = "";	
	
	/**
	 * The type of comparison to perform (over or under)
	 */
	public var compare:String = "";	
	
	/**
	 * The type of data to compare.
	 */
	public var criteria:String = "";	
	
	/**
	 * Internal vars
	 */
	public var lastDismissedTime:Number;
    public var lastExtreme:String;
    public var lastExtremeTime:Number;
    public var lastDisplayTime:Number;
    public var lastResult:Number;
    public var noticeID:Number;
	
	/**
	 * Constants for levels of notification
     */
	public static var kNoNotice:Number = 0;
    public static var kNoteInBackground:Number = 1;
    public static var kBringToAttention:Number = 2;
	
	/**
	 * Standard constructor takes enough info to set up comparisons.
	 */
	public function AlertRuleItem( symbol:String, criteria:String, compare:String, value:String, alert: Number )
	{
		this.symbol = symbol;
		this.criteria = criteria;
		this.compare = compare;
		this.value = value;
		this.alert = alert;
	}
	
}