// Homeland Agent
//
// Copyright 2003 Macromedia

#include "shared/debugging.as"
#include "shared/interfaces.as"
#include "agentapi.as"

var gAppName = "Homeland";

var gAgentManager;	// callback to Central AgentManager API
var gHomelandService;		// web service that provides current homeland security status
var gStorage;				// local persistent storage for this application
var gCom;					// local connection to communicate with apps and pods

var gThinkInterval = null;	// interval controlling how often this agent thinks
var gOnline = false;		// whether we currently have a network connection

// constants for setting notice level
var kNoNotice = 0;
var kNoteInBackground = 1;
var kBringToAttention = 2;

// constant for how often this agent will think
var kThinkFrequency = 24 * 60 * 60 * 1000; // think every 24 hours

// associate threat levels with messages
var gLevels = new Array();
gLevels["SEVERE"] = {message: "Severe Condition (Red)"};
gLevels["HIGH"] = {message: "High Condition (Orange)"};
gLevels["ELEVATED"] = {message: "Elevated Condition (Yellow)"};
gLevels["GUARDED"] = {message: "Guarded Condition (Blue)"};
gLevels["LOW"] = {message: "Low Condition (Green)"};
gLevels["UNKNOWN"] = {message: "Can't access Department of Homeland Security"};


//-------------------------------------------------------------------
// Initialization
//

function initStorage()
{
	gStorage = SharedObject.getLocal("homeland");
	
	// DEBUG: uncomment the lines below to reset every time we launch
	// gStorage.data.threat = undefined;
	
	if (gStorage.data.threat == undefined)
	{
		gStorage.data.threat = "unknown";
		gStorage.data.notify = kBringToAttention;
	}
}


//-------------------------------------------------------------------
// Main agent activity
//

function think()
{
	traceAgent("thinking");
	
	if (gOnline)
	{
		// call web service
		threatRequest = gHomelandService.advisoryAlert();
		
		// handle the result when it returns
		threatRequest.onResult = function(result)
		{
			traceAgent("level="+result);
			result = result.toUpperCase();
			
			// if it changed, broadcast to apps and tiles
			if (gStorage.data.threat != result)
			{
				gStorage.data.threat = result;
				
				// send the current threat level to my apps/pods
				gCom.setThreat(gStorage.data.threat);
				
				// if user would like to be notified as well, do so
				if (gStorage.data.notify > 0)
				{
					var noticeName = "Advisory: "+result.toLowerCase();
					var description = "\rHomeland Security advisory:\r\r"+gLevels[result].message;
					postNotice(noticeName, description, (gStorage.data.notify == kBringToAttention));
				}
			}
		}
	}
}

function postNotice(name, description, alert)
{
	notice = new Object();
	notice.name = name;
	notice.description = description;
	
	notice.alert = alert;
	// notice.engageString = "Show";
	notice.navigate = false;
	
	var noticeID = gAgentManager.addNotice(notice, {level: gStorage.data.threat});
	return noticeID;
}

function startThinking()
{
	traceAgent("think every "+(kThinkFrequency/1000/60/60)+" hrs");
	
	think();
	
	// think again later
	gThinkInterval = setInterval(think, kThinkFrequency);
}

function stopThinking()
{
	mytrace("stop thinking");
	if (gThinkInterval != null)
	{
		clearInterval(gThinkInterval);
		gThinkInterval = null;
	}
}


//-------------------------------------------------------------------
// Central Event Handling
//

function onActivate(agentManager, agentID, initialData)
{
	mytrace("activate: agentManager="+agentManager+" agentID="+agentID+" initialData="+initialData);
	
	gAgentManager = agentManager;

	// begin local communication service between this agent and apps/pods
	gCom = Central.LCService.createServer(HomelandService, this, false);

	// get reference to web service
	gHomelandService = new WebService("http://nbo02.macromedia.com/services/homeland.cfc?wsdl");
	
	onNetworkChange(gAgentManager.isConnected());
	
	// send the current threat level to my apps/pods
	gCom.setThreat(gStorage.data.threat);
}

function onDeactivate()
{
	traceAgent("deactivated");
	stopThinking();
	gCom.close();
}

function onNetworkChange(connected)
{
	traceAgent((connected ? "online" : "offline"));

	gOnline = connected;
	
	if (gOnline)
	{
		startThinking();
	}
	else
	{
		stopThinking();
	}
}


//-------------------------------------------
// Initialization

initStorage();
Central.initAgent(this, this);
