// Homeland Security Pod
// Copyright 2003 Macromedia

#include "shared/debugging.as"
#include "shared/interfaces.as"

var gAppName:String = "HomelandPod";
var gConsole:mx.central.Console;	// callback for the console
var gID;				// pod's ID number

var gThreat:String = "unknown";
var gCom;				// local connection listener to communicate with agent
var gOnline:Boolean = true;	// assume we're online unless we hear otherwise

// associate threat levels with messages
var gLevels:Array = new Array();
gLevels["SEVERE"] = {color: 0xFF0000, message: "Severe Risk of\rTerrorist Attacks"};
gLevels["HIGH"] = {color: 0xFF6600, message: "High Risk of\rTerrorist Attacks"};
gLevels["ELEVATED"] = {color: 0xFFCC00, message: "Significant Risk of\rTerrorist Attacks"};
gLevels["GUARDED"] = {color: 0x0099FF, message: "General Risk of\rTerrorist Attacks"};
gLevels["LOW"] = {color: 0x66CC66, message: "Low Risk of\rTerrorist Attacks"};


//-------------------------------------------------------------------
// Initialization
//

function setThreat(level)
{
	//mytrace("setThreat "+level);
	gThreat = level;
	refreshDisplay();
}


//-------------------------------------------------------------------
// Central Event Handling
//

function onActivate(console, id, viewerID, position, baseTabIndex, initialData)
{
	mytrace("onActivate id="+id+" viewerID="+viewerID);
	
	// save references to the console and the ID of this pod
	// we don't really use them yet, but as we add features, we'll probably use them
	gConsole = console;
	gID = id;
	gAppName += viewerID;
	
	// establish local connection to agent for data
	gCom = Central.LCService.createClient( HomelandService, gAppName, this, false );
	gCom.getThreat();

	onNetworkChange(gConsole.isConnected());

	refreshDisplay();
}

function onDeactivate()
{
	mytrace("deactivate");
	gCom.close();
}

function onNetworkChange(online)
{
	mytrace("online="+(online ? "true" : "false"));
	gOnline = online;
}


//-------------------------------------------------------------------
// Button Events
//

// clicking on the level text or background takes you to the DHS web site
fLevel.onRelease = function()
{
	getURL("http://www.dhs.gov/dhspublic/display?theme=29");
}
fBackground.onRelease = fLevel.onRelease;

// rolling over the little color boxes shows the various states
fGreen.onRollOver = function() { setDisplay("LOW"); }
fGreen.onRollOut = refreshDisplay;
fBlue.onRollOver = function() { setDisplay("GUARDED"); }
fBlue.onRollOut = refreshDisplay;
fYellow.onRollOver = function() { setDisplay("ELEVATED"); }
fYellow.onRollOut = refreshDisplay;
fOrange.onRollOver = function() { setDisplay("HIGH"); }
fOrange.onRollOut = refreshDisplay;
fRed.onRollOver = function() { setDisplay("SEVERE"); }
fRed.onRollOut = refreshDisplay;


//-------------------------------------------------------------------
// View Updating
//

function setDisplay(threat)
{
	fLevel.fDisplay.text = threat;
	fDescription.text = gLevels[threat].message;
	
	// set color of background to match threat level
	var bColor = new Color(fBackground);
	bColor.setRGB(gLevels[threat].color);
	delete bColor;
}

function refreshDisplay()
{
	//mytrace("refreshDisplay "+gThreat);
	setDisplay(gThreat);
}

//-------------------------------------------------------------------
// Agent Communication
//

// Handle result from calling getThreat API on our agent
function getThreat_Result(result)
{
	setThreat(result);
}

// Handle calls from our agent to set threat level
function setThreat(level)
{
	//mytrace("setThreat "+level);
	gThreat = level;
	refreshDisplay();
}


//-------------------------------------------------------------------
// Initialization
//

// let Central know we are ready
Central.initPod(this, this);
